@@ -157,16 +157,16 @@ void ocl_get_device(){
             clGetDeviceInfo(ocl_device, CL_DEVICE_MAX_CLOCK_FREQUENCY , sizeof(cl_uint), &mem, NULL);
             printf("%d CL_DEVICE_MAX_CLOCK_FREQUENCY :\t%d\n", i,mem);
             clGetDeviceInfo(ocl_device, CL_DEVICE_LOCAL_MEM_SIZE, sizeof(cl_ulong), &mem2, NULL);
-            printf("%d CL_DEVICE_LOCAL_MEM_SIZE :\t%I64d KB\n", i, mem2/1024);
+            printf("%d CL_DEVICE_LOCAL_MEM_SIZE :\t%llu KB\n", i, mem2/1024);
             clGetDeviceInfo(ocl_device, CL_DEVICE_GLOBAL_MEM_SIZE, sizeof(cl_ulong), &mem2, NULL);
-            printf("%d CL_DEVICE_GLOBAL_MEM_SIZE: %I64d MB\n", i, mem2/1024/1024);
+            printf("%d CL_DEVICE_GLOBAL_MEM_SIZE: %llu MB\n", i, mem2/1024/1024);
             clGetDeviceInfo(ocl_device, CL_DEVICE_MAX_MEM_ALLOC_SIZE, sizeof(cl_ulong), &mem2, NULL);
-            printf("%d CL_DEVICE_MAX_MEM_ALLOC_SIZE: %I64d MB\n", i, mem2/1024/1024);
+            printf("%d CL_DEVICE_MAX_MEM_ALLOC_SIZE: %llu MB\n", i, mem2/1024/1024);
             clGetDeviceInfo(ocl_device, CL_DEVICE_MAX_PARAMETER_SIZE, sizeof(size_t), &arg_nr, NULL);
-            printf("%d CL_DEVICE_MAX_PARAMETER_SIZE: %d MB\n", i, arg_nr);
+            printf("%d CL_DEVICE_MAX_PARAMETER_SIZE: %ld MB\n", i, arg_nr);
 
             clGetDeviceInfo(ocl_device, CL_DEVICE_MAX_WORK_GROUP_SIZE, sizeof(size_t), &arg_nr, NULL);
-            printf("%d CL_DEVICE_MAX_WORK_GROUP_SIZE: %d \n", i, arg_nr);
+            printf("%d CL_DEVICE_MAX_WORK_GROUP_SIZE: %ld \n", i, arg_nr);
             MAX_THREADS_WORKGROUP = (modelica_integer)arg_nr;   //default number of threads is the max number of threads!
 
             clGetDeviceInfo(ocl_device, CL_DEVICE_PREFERRED_VECTOR_WIDTH_DOUBLE  , sizeof(cl_uint), &mem, NULL);
@@ -299,11 +299,11 @@ void ocl_build_p_from_src(){
     printf("--- Building OpenCL program \n");
 #endif
 
-    char options[100];
-    const char* flags = "-I\"";
-    const char* OMEXT = "/include/omc/c/\"";
-
+    char options[1000];
+    const char* flags = "-Werror -I";
+    const char* OMEXT = "/include/omc/c/";
 
+    // TODO: Make sure to remove spaces from OMHOME
     strcpy(options, flags);
     strcat(options, OMHOME);
     strcat(options, OMEXT);
@@ -486,7 +486,7 @@ void ocl_execute_kernel(cl_kernel kernel){
 }
 
 
-void ocl_set_num_threads(integer_array_t global_threads_in, integer_array_t local_threads_in){
+void ocl_set_num_threads(integer_array global_threads_in, integer_array local_threads_in){
 
     WORK_DIM = global_threads_in.dim_size[0];
 
