@@ -183,11 +183,11 @@ int getAnalyticalJacobianLis(DATA* data, threadData_t *threadData, int sysNumber
 /*! \fn wrapper_fvec_lis for the residual function
  *
  */
-static int wrapper_fvec_lis(double* x, double* f, void** data, int sysNumber)
+static int wrapper_fvec_lis(double* x, double* f, RESIDUAL_USERDATA* resUserData , int sysNumber)
 {
   int iflag = 0;
 
-  (*((DATA*)data[0])->simulationInfo->linearSystemData[sysNumber].residualFunc)(data, x, f, &iflag);
+  resUserData->data->simulationInfo->linearSystemData[sysNumber].residualFunc(resUserData, x, f, &iflag);
   return 0;
 }
 
@@ -200,7 +200,7 @@ static int wrapper_fvec_lis(double* x, double* f, void** data, int sysNumber)
  */
 int solveLis(DATA *data, threadData_t *threadData, int sysNumber, double* aux_x)
 {
-  void *dataAndThreadData[2] = {data, threadData};
+  RESIDUAL_USERDATA resUserData = {.data=data, .threadData=threadData, .solverData=NULL};
   LINEAR_SYSTEM_DATA* systemData = &(data->simulationInfo->linearSystemData[sysNumber]);
   DATA_LIS* solverData = (DATA_LIS*)systemData->parDynamicData[omc_get_thread_num()].solverData[0];
 
@@ -211,9 +211,9 @@ int solveLis(DATA *data, threadData_t *threadData, int sysNumber, double* aux_x)
 
   int indexes[2] = {1,eqSystemNumber};
   double tmpJacEvalTime;
-  infoStreamPrintWithEquationIndexes(LOG_LS, 0, indexes, "Start solving Linear System %d (size %d) at time %g with Lis Solver",
-         eqSystemNumber, (int) systemData->size,
-         data->localData[0]->timeValue);
+  infoStreamPrintWithEquationIndexes(LOG_LS, omc_dummyFileInfo, 0, indexes,
+    "Start solving Linear System %d (size %d) at time %g with Lis Solver",
+    eqSystemNumber, (int) systemData->size, data->localData[0]->timeValue);
 
   /* set old values as start value for the iteration */
   for(i=0; i<n; i++){
@@ -243,7 +243,7 @@ int solveLis(DATA *data, threadData_t *threadData, int sysNumber, double* aux_x)
 
     /* calculate vector b (rhs) */
     memcpy(solverData->work, aux_x, sizeof(double)*solverData->n_row);
-    wrapper_fvec_lis(solverData->work, systemData->parDynamicData[omc_get_thread_num()].b, dataAndThreadData, sysNumber);
+    wrapper_fvec_lis(solverData->work, systemData->parDynamicData[omc_get_thread_num()].b, &resUserData, sysNumber);
 
 	/* set b vector */
     for(i=0; i<n; i++) {
@@ -294,13 +294,13 @@ int solveLis(DATA *data, threadData_t *threadData, int sysNumber, double* aux_x)
         aux_x[i] += solverData->work[i];
 
       /* update inner equations */
-      wrapper_fvec_lis(aux_x, solverData->work, dataAndThreadData, sysNumber);
+      wrapper_fvec_lis(aux_x, solverData->work, &resUserData, sysNumber);
       residualNorm = _omc_gen_euclideanVectorNorm(solverData->work, solverData->n_row);
 
       if ((isnan(residualNorm)) || (residualNorm>1e-4)){
-        warningStreamPrint(LOG_LS, 0,
-            "Failed to solve linear system of equations (no. %d) at time %f. Residual norm is %.15g.",
-            (int)systemData->equationIndex, data->localData[0]->timeValue, residualNorm);
+        warningStreamPrintWithLimit(LOG_LS, 0, ++(systemData->numberOfFailures) /* Update counter */, data->simulationInfo->maxWarnDisplays,
+                                    "Failed to solve linear system of equations (no. %d) at time %f. Residual norm is %.15g.",
+                                    (int)systemData->equationIndex, data->localData[0]->timeValue, residualNorm);
         success = 0;
       }
     } else {
@@ -325,9 +325,9 @@ int solveLis(DATA *data, threadData_t *threadData, int sysNumber, double* aux_x)
   }
   else
   {
-    warningStreamPrint(LOG_STDOUT, 0,
-      "Failed to solve linear system of equations (no. %d) at time %f, system status %d.",
-        (int)systemData->equationIndex, data->localData[0]->timeValue, err);
+    warningStreamPrintWithLimit(LOG_LS, 0, ++(systemData->numberOfFailures) /* Update counter */, data->simulationInfo->maxWarnDisplays,
+                                "Failed to solve linear system of equations (no. %d) at time %f, system status %d.",
+                                  (int)systemData->equationIndex, data->localData[0]->timeValue, err);
   }
 
   return success;
