@@ -50,17 +50,23 @@
 #include "epsilon.h"
 #include "fmi_events.h"
 #include "stateset.h"
+#include "spatialDistribution.h"
 #include "../../meta/meta_modelica.h"
 
 #ifdef USE_PARJAC
   #include <omp.h>
 #endif
 
+/* Private function prototypes */
+void* syncTimerListAlloc(const void* data);
+void syncTimerListFree(void* data);
+void syncTimerListCopy(void* dest, const void* src);
+
 int maxEventIterations = 20;
-double linearSparseSolverMaxDensity = 0.2;
+double linearSparseSolverMaxDensity = DEFAULT_FLAG_LSS_MAX_DENSITY;
 int linearSparseSolverMinSize = DEFAULT_FLAG_LSS_MIN_SIZE;
-double nonlinearSparseSolverMaxDensity = 0.2;
-int nonlinearSparseSolverMinSize = DEFAULT_FLAG_NLS_MIN_SIZE;
+double nonlinearSparseSolverMaxDensity = DEFAULT_FLAG_NLSS_MAX_DENSITY;
+int nonlinearSparseSolverMinSize = DEFAULT_FLAG_NLSS_MIN_SIZE;
 double maxStepFactor = 1e12;
 double newtonXTol = 1e-12;
 double newtonFTol = 1e-12;
@@ -97,9 +103,9 @@ void updateDiscreteSystem(DATA *data, threadData_t *threadData)
 {
   TRACE_PUSH
   int numEventIterations = 0;
-  int discreteChanged = 0;
-  modelica_boolean relationChanged = 0;
-  data->simulationInfo->needToIterate = 0;
+  modelica_boolean discreteChanged = FALSE;
+  modelica_boolean relationChanged = FALSE;
+  data->simulationInfo->needToIterate = FALSE;
 
   data->simulationInfo->callStatistics.updateDiscreteSystem++;
 
@@ -376,11 +382,11 @@ void printParameters(DATA *data, int stream)
  * Use to print e.g. sparse Jacobian matrix.
  * Only prints if stream is active and sparse pattern is non NULL and of size > 0.
  *
- * @param [in]  sparsePattern   Matrix to print.
- * @param [in]  sizeRows        Number of rows of matrix.
- * @param [in]  sizeCols        Number of columns of matrix.
- * @param [in]  stream          Steam to print to.
- * @param [in]  name            Name of matrix.
+ * @param sparsePattern   Matrix to print.
+ * @param sizeRows        Number of rows of matrix.
+ * @param sizeCols        Number of columns of matrix.
+ * @param stream          Steam to print to.
+ * @param name            Name of matrix.
  */
 void printSparseStructure(SPARSE_PATTERN *sparsePattern, int sizeRows, int sizeCols, int stream, const char* name)
 {
@@ -396,14 +402,14 @@ void printSparseStructure(SPARSE_PATTERN *sparsePattern, int sizeRows, int sizeC
   /* Catch empty sparsePattern */
   if (sparsePattern == NULL || sizeRows <= 0 || sizeCols <= 0)
   {
-    infoStreamPrint(stream, 0, "No sparse strucutre available for \"%s\".", name);
+    infoStreamPrint(stream, 0, "No sparse structure available for \"%s\".", name);
     return;
   }
 
   buffer = (char*)omc_alloc_interface.malloc(sizeof(char)* 2*sizeCols + 4);
 
   infoStreamPrint(stream, 1, "Sparse structure of %s [size: %ux%u]", name, sizeRows, sizeCols);
-  infoStreamPrint(stream, 0, "%u nonzero elements", sparsePattern->numberOfNoneZeros);
+  infoStreamPrint(stream, 0, "%u non-zero elements", sparsePattern->numberOfNonZeros);
 
   infoStreamPrint(stream, 1, "Transposed sparse structure (rows: states)");
   i=0;
@@ -430,6 +436,61 @@ void printSparseStructure(SPARSE_PATTERN *sparsePattern, int sizeRows, int sizeC
   messageClose(stream);
 }
 
+/**
+ * @brief Check if sparsity pattern can describe regular matrix.
+ *
+ * @param sparsePattern       Sparsity pattern.
+ * @param nlsSize             size of non-linear loop / size of square matrix.
+ * @param stream              Stream for logging.
+ * @return modelica_boolean   False if sparsity pattern can't describe regular matrix, true otherwise.
+ */
+modelica_boolean sparsitySanityCheck(SPARSE_PATTERN *sparsePattern, int nlsSize, int stream)
+{
+  int i;
+  char *colCheck;
+
+  if (sparsePattern == NULL || nlsSize <= 0)
+  {
+    warningStreamPrint(stream, 0, "No sparse structure available.");
+    return FALSE;
+  }
+
+  if (sparsePattern->numberOfNonZeros < nlsSize) {
+    warningStreamPrint(stream, 0, "Sparsity pattern of %dx%d has ony %d non-zero elements.", nlsSize,nlsSize, sparsePattern->numberOfNonZeros);
+    return FALSE;
+  }
+
+  /* check rows (or cols?) */
+  for(i=1; i < nlsSize; i++)
+  {
+    if(sparsePattern->leadindex[i] == sparsePattern->leadindex[i-1]) {
+      warningStreamPrint(stream, 0, "Sparsity pattern row %d has no non-zero elements.", i);
+      return FALSE;
+    }
+  }
+
+  /* check cols (or rows?) */
+  colCheck = (char*) calloc(nlsSize, sizeof(char));
+
+  for(i=0; i < sparsePattern->leadindex[nlsSize]; i++)
+  {
+    colCheck[sparsePattern->index[i]] = TRUE;
+  }
+
+  for(i=0; i < nlsSize; i++)
+  {
+    if(!colCheck[i]) {
+      warningStreamPrint(stream, 0, "Sparsity pattern column %d has no non-zero elements.", i);
+      free(colCheck);
+      return FALSE;
+    }
+  }
+
+  free(colCheck);
+  return TRUE;
+}
+
+
 #ifdef USE_DEBUG_OUTPUT
 /*! \fn printRelationsDebug
  *
@@ -503,7 +564,7 @@ void printZeroCrossings(DATA *data, int stream)
   {
     int *eq_indexes;
     const char *exp_str = data->callback->zeroCrossingDescription(i,&eq_indexes);
-    infoStreamPrintWithEquationIndexes(stream, 0, eq_indexes, "[%ld] (pre: %2.g) %2.g = %s", i+1, data->simulationInfo->zeroCrossingsPre[i], data->simulationInfo->zeroCrossings[i], exp_str);
+    infoStreamPrintWithEquationIndexes(stream, omc_dummyFileInfo, 0, eq_indexes, "[%ld] (pre: %2.g) %2.g = %s", i+1, data->simulationInfo->zeroCrossingsPre[i], data->simulationInfo->zeroCrossings[i], exp_str);
   }
   messageClose(stream);
 
@@ -574,6 +635,44 @@ void copyRingBufferSimulationData(DATA *data, threadData_t *threadData, SIMULATI
   TRACE_POP
 }
 
+/*
+* print information about ring buffer simulation data
+*/
+void printRingBufferSimulationData(RINGBUFFER *rb, DATA* data)
+{
+  TRACE_PUSH
+
+  for (int i = 0; i < ringBufferLength(rb); i++)
+  {
+    messageClose(LOG_STDOUT);
+    SIMULATION_DATA *sdata = (SIMULATION_DATA *)getRingData(rb, i);
+    infoStreamPrint(LOG_STDOUT, 1, "Time: %g ", sdata->timeValue);
+
+    infoStreamPrint(LOG_STDOUT, 1, "RingBuffer Real Variable");
+    for (int j = 0; j < data->modelData->nVariablesReal; ++j)
+    {
+      infoStreamPrint(LOG_STDOUT, 0, "%d: %s = %g ", j+1, data->modelData->realVarsData[j].info.name, sdata->realVars[j]);
+    }
+    messageClose(LOG_STDOUT);
+
+    infoStreamPrint(LOG_STDOUT, 1, "RingBuffer Integer Variable");
+    for (int j = 0; j < data->modelData->nVariablesInteger; ++j)
+    {
+      infoStreamPrint(LOG_STDOUT, 0, "%d: %s = %li ", j+1, data->modelData->integerVarsData[j].info.name, sdata->integerVars[j]);
+    }
+    messageClose(LOG_STDOUT);
+
+    infoStreamPrint(LOG_STDOUT, 1, "RingBuffer Boolean Variable");
+    for(int j = 0; j < data->modelData->nVariablesBoolean; ++j)
+    {
+      infoStreamPrint(LOG_STDOUT, 0, "%d: %s = %s ", j+1, data->modelData->booleanVarsData[j].info.name, sdata->booleanVars[j] ? "true" : "false");
+    }
+    messageClose(LOG_STDOUT);
+  }
+
+  TRACE_POP
+}
+
 /* \fn restoreExtrapolationDataOld
  *
  *  Restores variables (states, derivatives and algebraic).
@@ -859,15 +958,16 @@ void storeRelations(DATA* data)
   TRACE_POP
 }
 
-/*! \fn getNextSampleTimeFMU
+/**
+ * @brief Get time of next sample event if one is defined.
  *
- *  function return next sample time.
+ * Function returns 0 if a time is defined and -1 otherwise.
  *
- *  \param [in]  [data]
- *
- *  \author wbraun
+ * @param data                  Data
+ * @param nextSampleEvent       On output time of next sample event.
+ * @return int                  1 if a sample event is defined, 0 otherwise
  */
-double getNextSampleTimeFMU(DATA *data)
+int getNextSampleTimeFMU(DATA *data, double *nextSampleEvent)
 {
   TRACE_PUSH
 
@@ -875,11 +975,12 @@ double getNextSampleTimeFMU(DATA *data)
   {
     infoStreamPrint(LOG_EVENTS, 0, "Next event time = %f", data->simulationInfo->nextSampleEvent);
     TRACE_POP
-    return data->simulationInfo->nextSampleEvent;
+    *nextSampleEvent = data->simulationInfo->nextSampleEvent;
+    return 1 /* TRUE */;
   }
 
   TRACE_POP
-  return -1;
+  return 0 /* FALSE */;
 }
 
 /*! \fn initializeDataStruc
@@ -907,7 +1008,11 @@ void initializeDataStruc(DATA *data, threadData_t *threadData)
   for(i=0; i<SIZERINGBUFFER; i++)
   {
     /* set time value */
-    tmpSimData.timeValue = 0;
+    /*
+    * fix issue #11855, always take the startTime provided in modeldescription.xml
+    * to handle models that have startTime > 0 (e.g) startTime = 0.2
+    */
+    tmpSimData.timeValue = data->simulationInfo->startTime;
     /* buffer for all variable values */
     tmpSimData.realVars = (modelica_real*) calloc(data->modelData->nVariablesReal, sizeof(modelica_real));
     assertStreamPrint(threadData, 0 == data->modelData->nVariablesReal || 0 != tmpSimData.realVars, "out of memory");
@@ -923,7 +1028,7 @@ void initializeDataStruc(DATA *data, threadData_t *threadData)
   }
   data->localData = (SIMULATION_DATA**) omc_alloc_interface.malloc_uncollectable(SIZERINGBUFFER * sizeof(SIMULATION_DATA));
   memset(data->localData, 0, SIZERINGBUFFER * sizeof(SIMULATION_DATA));
-  rotateRingBuffer(data->simulationData, 0, (void**) data->localData);
+  lookupRingBuffer(data->simulationData, (void**) data->localData);
 
   /* create modelData var arrays */
   data->modelData->realVarsData = (STATIC_REAL_DATA*) omc_alloc_interface.malloc_uncollectable(data->modelData->nVariablesReal * sizeof(STATIC_REAL_DATA));
@@ -947,9 +1052,15 @@ void initializeDataStruc(DATA *data, threadData_t *threadData)
   data->simulationInfo->nextSampleTimes = (double*) calloc(data->modelData->nSamples, sizeof(double));
   data->simulationInfo->samples = (modelica_boolean*) calloc(data->modelData->nSamples, sizeof(modelica_boolean));
 
-  data->modelData->clocksInfo = (CLOCK_INFO*) omc_alloc_interface.malloc_uncollectable(data->modelData->nClocks * sizeof(CLOCK_INFO));
-  data->modelData->subClocksInfo = (SUBCLOCK_INFO*) omc_alloc_interface.malloc_uncollectable(data->modelData->nSubClocks * sizeof(SUBCLOCK_INFO));
-  data->simulationInfo->clocksData = (CLOCK_DATA*) calloc(data->modelData->nClocks, sizeof(CLOCK_DATA));
+  if (data->modelData->nBaseClocks > 0) {
+    data->simulationInfo->baseClocks = (BASECLOCK_DATA*) calloc(data->modelData->nBaseClocks, sizeof(BASECLOCK_DATA));
+    data->simulationInfo->intvlTimers = allocList(syncTimerListAlloc, syncTimerListFree, syncTimerListCopy);
+  } else {
+    data->simulationInfo->baseClocks = NULL;
+    data->simulationInfo->intvlTimers = NULL;
+  }
+
+  data->simulationInfo->spatialDistributionData = allocSpatialDistribution(data->modelData->nSpatialDistributions);
 
   /* set default solvers for algebraic loops */
 #if !defined(OMC_MINIMAL_RUNTIME)
@@ -972,11 +1083,13 @@ void initializeDataStruc(DATA *data, threadData_t *threadData)
   data->simulationInfo->relations = (modelica_boolean*) calloc(data->modelData->nRelations, sizeof(modelica_boolean));
   data->simulationInfo->relationsPre = (modelica_boolean*) calloc(data->modelData->nRelations, sizeof(modelica_boolean));
   data->simulationInfo->storedRelations = (modelica_boolean*) calloc(data->modelData->nRelations, sizeof(modelica_boolean));
-  data->simulationInfo->zeroCrossingIndex = (long*) malloc(data->modelData->nZeroCrossings*sizeof(long));
   data->simulationInfo->mathEventsValuePre = (modelica_real*) malloc(data->modelData->nMathEvents*sizeof(modelica_real));
+  data->simulationInfo->zeroCrossingIndex = (long*) malloc(data->modelData->nZeroCrossings*sizeof(long));
   /* initialize zeroCrossingsIndex with corresponding index is used by events lists */
   for(i=0; i<data->modelData->nZeroCrossings; i++)
     data->simulationInfo->zeroCrossingIndex[i] = (long)i;
+  data->simulationInfo->states_left = (modelica_real*) malloc(data->modelData->nStates * sizeof(modelica_real));
+  data->simulationInfo->states_right = (modelica_real*) malloc(data->modelData->nStates * sizeof(modelica_real));
 
   /* buffer for old values */
   data->simulationInfo->realVarsOld = (modelica_real*) calloc(data->modelData->nVariablesReal, sizeof(modelica_real));
@@ -1002,6 +1115,7 @@ void initializeDataStruc(DATA *data, threadData_t *threadData)
   data->simulationInfo->outputVars = (modelica_real*) calloc(data->modelData->nOutputVars, sizeof(modelica_real));
   data->simulationInfo->setcVars = (modelica_real*) calloc(data->modelData->nSetcVars, sizeof(modelica_real));
   data->simulationInfo->datainputVars = (modelica_real*) calloc(data->modelData->ndataReconVars, sizeof(modelica_real));
+  data->simulationInfo->setbVars = (modelica_real*) calloc(data->modelData->nSetbVars, sizeof(modelica_real));
 
 #if !defined(OMC_NUM_MIXED_SYSTEMS) || OMC_NUM_MIXED_SYSTEMS>0
   /* buffer for mixed systems */
@@ -1093,6 +1207,8 @@ void initializeDataStruc(DATA *data, threadData_t *threadData)
   /*  switches used to evaluate the system */
   data->simulationInfo->solveContinuous = 0;
   data->simulationInfo->noThrowDivZero = 0;
+  data->simulationInfo->noThrowAsserts = 0;
+  data->simulationInfo->needToReThrow = 0;
   data->simulationInfo->discreteCall = 0;
 
   /* initialize model error code */
@@ -1104,7 +1220,11 @@ void initializeDataStruc(DATA *data, threadData_t *threadData)
   assertStreamPrint(threadData, 0 == data->modelData->nDelayExpressions || 0 != data->simulationInfo->delayStructure, "out of memory");
 
   for(i=0; i<data->modelData->nDelayExpressions; i++)
+  {
+    // TODO: Calculate how big ringbuffer should be for each delay expression
+    // can be estimated by lower bound delayMax/stepSize
     data->simulationInfo->delayStructure[i] = allocRingBuffer(1024, sizeof(TIME_AND_VALUE));
+  }
 #endif
 
 #if !defined(OMC_NO_STATESELECTION)
@@ -1177,8 +1297,12 @@ void deInitializeDataStruc(DATA *data)
   free(data->simulationInfo->nextSampleTimes);
   free(data->simulationInfo->samples);
 
-  omc_alloc_interface.free_uncollectable(data->modelData->clocksInfo);
-  omc_alloc_interface.free_uncollectable(data->modelData->subClocksInfo);
+  free(data->simulationInfo->baseClocks);
+  freeList(data->simulationInfo->intvlTimers);
+  data->simulationInfo->intvlTimers = NULL;
+
+  freeSpatialDistribution(data->simulationInfo->spatialDistributionData, data->modelData->nSpatialDistributions);
+  free(data->simulationInfo->spatialDistributionData);
 
   /* free simulationInfo arrays */
   free(data->simulationInfo->zeroCrossings);
@@ -1187,7 +1311,10 @@ void deInitializeDataStruc(DATA *data)
   free(data->simulationInfo->relations);
   free(data->simulationInfo->relationsPre);
   free(data->simulationInfo->storedRelations);
+  free(data->simulationInfo->mathEventsValuePre);
   free(data->simulationInfo->zeroCrossingIndex);
+  free(data->simulationInfo->states_left);
+  free(data->simulationInfo->states_right);
 
   /* free buffer for old state variables */
   free(data->simulationInfo->realVarsOld);
@@ -1229,11 +1356,17 @@ void deInitializeDataStruc(DATA *data)
   /* free buffer for state sets */
   omc_alloc_interface.free_uncollectable(data->simulationInfo->daeModeData);
 
+  /* buffer for inline Data */
+  free(data->simulationInfo->inlineData->algVars);
+  free(data->simulationInfo->inlineData->algOldVars);
+  omc_alloc_interface.free_uncollectable(data->simulationInfo->inlineData);
+
   /* free inputs and output */
   free(data->simulationInfo->inputVars);
   free(data->simulationInfo->outputVars);
   free(data->simulationInfo->setcVars);
   free(data->simulationInfo->datainputVars);
+  free(data->simulationInfo->setbVars);
 
   /* free external objects buffer */
   free(data->simulationInfo->extObjs);
@@ -1265,6 +1398,9 @@ void deInitializeDataStruc(DATA *data)
     FREE_VARS(nSensitivityVars, realSensitivityData)
   }
 
+  /* Free model info xml data */
+  modelInfoDeinit(&(data->modelData->modelDataXml));
+
   TRACE_POP
 }
 
@@ -1285,27 +1421,27 @@ void setZCtol(double relativeTol)
 }
 
 /* TODO: fix this */
-modelica_boolean LessZC(double a, double b, modelica_boolean direction)
+modelica_boolean LessZC(double a, double b, double a_nominal, double b_nominal, modelica_boolean direction)
 {
-  double eps = tolZC * fmax(fabs(a), fabs(b)) + tolZC;
+  double eps = tolZC * (fmax(fabs(a), fabs(b)) + fmax(fabs(a_nominal), fabs(b_nominal)));
   return direction ? (a - b <= eps) : (a - b <= -eps);
 }
 
-modelica_boolean LessEqZC(double a, double b, modelica_boolean direction)
+modelica_boolean LessEqZC(double a, double b, double a_nominal, double b_nominal, modelica_boolean direction)
 {
-  return !GreaterZC(a, b, !direction);
+  return !GreaterZC(a, b, a_nominal, b_nominal, !direction);
 }
 
 /* TODO: fix this */
-modelica_boolean GreaterZC(double a, double b, modelica_boolean direction)
+modelica_boolean GreaterZC(double a, double b, double a_nominal, double b_nominal, modelica_boolean direction)
 {
-  double eps = tolZC * fmax(fabs(a), fabs(b)) + tolZC;
+  double eps = tolZC * (fmax(fabs(a), fabs(b)) + fmax(fabs(a_nominal), fabs(b_nominal)));
   return direction ? (a - b >= -eps ) : (a - b >= eps);
 }
 
-modelica_boolean GreaterEqZC(double a, double b, modelica_boolean direction)
+modelica_boolean GreaterEqZC(double a, double b, double a_nominal, double b_nominal, modelica_boolean direction)
 {
-  return !LessZC(a, b, !direction);
+  return !LessZC(a, b, a_nominal, b_nominal, !direction);
 }
 
 modelica_boolean Less(double a, double b)
@@ -1421,13 +1557,17 @@ modelica_integer _event_mod_integer(modelica_integer x1, modelica_integer x2, mo
  */
 modelica_real _event_mod_real(modelica_real x1, modelica_real x2, modelica_integer index, DATA *data, threadData_t *threadData)
 {
+  modelica_real value;
+
   if(data->simulationInfo->discreteCall && !data->simulationInfo->solveContinuous)
   {
     data->simulationInfo->mathEventsValuePre[index] = x1;
     data->simulationInfo->mathEventsValuePre[index+1] = x2;
   }
 
-  return x1 - floor(x1 / x2) * x2;
+  value = _event_floor(x1 / x2, index+2, data);
+
+  return x1 - value * x2;
 }
 
 /*! \fn _event_div_integer
@@ -1451,8 +1591,8 @@ modelica_integer _event_div_integer(modelica_integer x1, modelica_integer x2, mo
   value1 = (modelica_integer)data->simulationInfo->mathEventsValuePre[index];
   value2 = (modelica_integer)data->simulationInfo->mathEventsValuePre[index+1];
 
-  assertStreamPrint(threadData, value2 != 0, "event_div_integer failt at time %f because x2 is zero!", data->localData[0]->timeValue);
-  return ldiv(value1, value2).quot;
+  assertStreamPrint(threadData, value2 != 0, "event_div_integer failed at time %f because x2 is zero!", data->localData[0]->timeValue);
+  return modelica_div_integer(value1, value2).quot;
 }
 
 /*! \fn _event_div_real
@@ -1487,59 +1627,37 @@ modelica_real _event_div_real(modelica_real x1, modelica_real x2, modelica_integ
 #endif
 }
 
+
+/**
+ * @brief Allocate memory for syncTimerList elements.
+ *
+ * @param data      Unused.
+ * @return void*    Allocated memory for LIST_NODE data.
+ */
+void* syncTimerListAlloc(const void* data) {
+  void* newElem = malloc(sizeof(SYNC_TIMER));
+  assertStreamPrint(NULL, newElem != NULL, "syncTimerListAlloc: Out of memory");
+  return newElem;
+}
+
+/**
+ * @brief Free memory allocated with syncTimerListAlloc.
+ *
+ * @param data      Void pointer, representing SYNC_TIMER.
+ */
+void syncTimerListFree(void* data) {
+  free(data);
+}
+
+/**
+ * @brief Copy data of syncTimerList elements.
+ *
+ * @param dest    Void pointer of destination data, representing SYNC_TIMER.
+ * @param src     Void pointer of source data, representing SYNC_TIMER.
+ */
+void syncTimerListCopy(void* dest, const void* src) {
+  memcpy(dest, src, sizeof(SYNC_TIMER));
+}
+
+
 int measure_time_flag=0;
-
-const char *context_string[CONTEXT_MAX] = {
- "context UNKNOWN",
- "context ODE evaluation",
- "context algebraic evaluation",
- "context event search",
- "context jacobian evaluation",
- "context symbolica jacobian evaluation"
-};
-
-/*! \fn setContext
- *
- *  \param [ref] [data]
- *  \param [in]  [currentTime]
- *  \param [in]  [currentContext]
- *
- * Set current context in simulation info object
- */
-void setContext(DATA* data, double* currentTime, int currentContext){
-  data->simulationInfo->currentContextOld =  data->simulationInfo->currentContext;
-  data->simulationInfo->currentContext =  currentContext;
-  infoStreamPrint(LOG_SOLVER_CONTEXT, 0, "+++ Set context %s +++ at time %f", context_string[currentContext], *currentTime);
-  if (currentContext == CONTEXT_JACOBIAN ||
-      currentContext == CONTEXT_SYM_JACOBIAN)
-  {
-    data->simulationInfo->currentJacobianEval = 0;
-  }
-}
-
-/*! \fn increaseJacContext
- *
- *  \param [ref] [data]
- *
- * Increase Jacobian column context in simulation info object
- */
-void increaseJacContext(DATA* data){
-  int currentContext = data->simulationInfo->currentContext;
-  if (currentContext == CONTEXT_JACOBIAN ||
-      currentContext == CONTEXT_SYM_JACOBIAN)
-  {
-    data->simulationInfo->currentJacobianEval++;
-    infoStreamPrint(LOG_SOLVER_CONTEXT, 0, "+++ Increase Jacobian column context %s +++ to %d", context_string[currentContext], data->simulationInfo->currentJacobianEval);
-  }
-}
-
-/*! \fn unsetContext
- *
- *  \param [ref] [data]
- *
- * Restores previous context in simulation info object
- */
-void unsetContext(DATA* data){
-  infoStreamPrint(LOG_SOLVER_CONTEXT, 0, "--- Unset context %s ---", context_string[data->simulationInfo->currentContext]);
-  data->simulationInfo->currentContext =  data->simulationInfo->currentContextOld;
-}
