@@ -279,7 +279,7 @@ void PlotWindowContainer::showDiagramWindow(ModelWidget *pModelWidget)
 void PlotWindowContainer::addPlotWindow()
 {
   try {
-    PlotWindow *pPlotWindow = new PlotWindow(QStringList(), this);
+    PlotWindow *pPlotWindow = new PlotWindow(QStringList(), this, false, OptionsDialog::instance()->getGeneralSettingsPage()->getToolbarIconSizeSpinBox()->value());
     pPlotWindow->setPlotType(PlotWindow::PLOT);
     pPlotWindow->setWindowTitle(getUniqueName("Plot : "));
     pPlotWindow->setTitle("");
@@ -315,7 +315,7 @@ void PlotWindowContainer::addPlotWindow()
 void PlotWindowContainer::addParametricPlotWindow()
 {
   try {
-    PlotWindow *pPlotWindow = new PlotWindow(QStringList(), this);
+    PlotWindow *pPlotWindow = new PlotWindow(QStringList(), this, false, OptionsDialog::instance()->getGeneralSettingsPage()->getToolbarIconSizeSpinBox()->value());
     pPlotWindow->setPlotType(PlotWindow::PLOTPARAMETRIC);
     pPlotWindow->setWindowTitle(getUniqueName("Parametric Plot : "));
     pPlotWindow->setTitle("");
@@ -350,7 +350,7 @@ void PlotWindowContainer::addParametricPlotWindow()
 void PlotWindowContainer::addArrayPlotWindow()
 {
   try {
-    PlotWindow *pPlotWindow = new PlotWindow(QStringList(), this);
+    PlotWindow *pPlotWindow = new PlotWindow(QStringList(), this, false, OptionsDialog::instance()->getGeneralSettingsPage()->getToolbarIconSizeSpinBox()->value());
     pPlotWindow->setPlotType(PlotWindow::PLOTARRAY);
     pPlotWindow->setWindowTitle(getUniqueName("Array Plot : "));
     pPlotWindow->setTitle("");
@@ -392,7 +392,7 @@ void PlotWindowContainer::addArrayPlotWindow()
 PlotWindow* PlotWindowContainer::addInteractivePlotWindow(QString owner, int port)
 {
   try {
-    PlotWindow *pPlotWindow = new PlotWindow(QStringList(), this, true);
+    PlotWindow *pPlotWindow = new PlotWindow(QStringList(), this, true, OptionsDialog::instance()->getGeneralSettingsPage()->getToolbarIconSizeSpinBox()->value());
     pPlotWindow->setPlotType(PlotWindow::PLOTINTERACTIVE);
     pPlotWindow->setInteractiveOwner(owner);
     pPlotWindow->setInteractivePort(port);
@@ -434,7 +434,7 @@ PlotWindow* PlotWindowContainer::addInteractivePlotWindow(QString owner, int por
 void PlotWindowContainer::addArrayParametricPlotWindow()
 {
   try {
-    PlotWindow *pPlotWindow = new PlotWindow(QStringList(), this);
+    PlotWindow *pPlotWindow = new PlotWindow(QStringList(), this, false, OptionsDialog::instance()->getGeneralSettingsPage()->getToolbarIconSizeSpinBox()->value());
     pPlotWindow->setPlotType(PlotWindow::PLOTARRAYPARAMETRIC);
     pPlotWindow->setWindowTitle(getUniqueName("Array Parametric Plot : "));
     pPlotWindow->setTitle("");
@@ -564,7 +564,7 @@ void PlotWindowContainer::clearPlotWindow()
   PlotWindow *pPlotWindow = getCurrentWindow();
   if (!pPlotWindow) {
     QMessageBox::information(this, QString(Helper::applicationName).append(" - ").append(Helper::information),
-                             tr("No plot window is active for clearing curves."), Helper::ok);
+                             tr("No plot window is active for clearing curves."), QMessageBox::Ok);
     return;
   }
   removePlotCurves(pPlotWindow);
@@ -580,15 +580,15 @@ void PlotWindowContainer::exportVariables()
 {
   PlotWindow *pPlotWindow = getCurrentWindow();
   if (!pPlotWindow) {
-    QMessageBox::information(this, QString("%1 - %2").arg(Helper::applicationName, Helper::information), tr("No plot window is active for exporting variables."), Helper::ok);
+    QMessageBox::information(this, QString("%1 - %2").arg(Helper::applicationName, Helper::information), tr("No plot window is active for exporting variables."), QMessageBox::Ok);
     return;
   }
   if (pPlotWindow->isPlotParametric() || pPlotWindow->isPlotArrayParametric()) {
-    QMessageBox::information(this, QString("%1 - %2").arg(Helper::applicationName, Helper::information), tr("Cannot export parametric plot."), Helper::ok);
+    QMessageBox::information(this, QString("%1 - %2").arg(Helper::applicationName, Helper::information), tr("Cannot export parametric plot."), QMessageBox::Ok);
     return;
   }
   if (pPlotWindow->getPlot()->getPlotCurvesList().isEmpty()) {
-    QMessageBox::information(this, QString("%1 - %2").arg(Helper::applicationName, Helper::information), tr("No variables are selected for exporting."), Helper::ok);
+    QMessageBox::information(this, QString("%1 - %2").arg(Helper::applicationName, Helper::information), tr("No variables are selected for exporting."), QMessageBox::Ok);
     return;
   }
 
@@ -606,7 +606,7 @@ void PlotWindowContainer::exportVariables()
         timeVector = pPlotCurve->mXAxisVector;
       }
       if (filePath.compare(pPlotCurve->getAbsoluteFilePath()) != 0) {
-        QMessageBox::information(this, QString("%1 - %2").arg(Helper::applicationName, Helper::information), tr("Not possible to export variables from different result files."), Helper::ok);
+        QMessageBox::information(this, QString("%1 - %2").arg(Helper::applicationName, Helper::information), tr("Not possible to export variables from different result files."), QMessageBox::Ok);
         return;
       }
       headers << QString("\"%1\"").arg(pPlotCurve->getYVariable());
